/*********************************************************************************

Copyright(c) 2005 Analog Devices, Inc. All Rights Reserved. 

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.  

$RCSfile: ezkitutilities.h,v $
$Revision: 1.6 $
$Date: 2005/11/11 22:15:29 $

Description:
			EZ-Kit utility routines
			
*********************************************************************************/

#ifndef EZKITUTILITIES_H
#define EZKITUTILITIES_H 


/*********************************************************************

Enumerations for the first and last buttons and LEDs

*********************************************************************/

#if defined(__ADSP_EDINBURGH__)			// ADSP-BF533 EZ-Kit specific info
#define EZ_FIRST_LED				(4)				// first LED number
#define EZ_LAST_LED					(9)				// last LED number
#define EZ_FIRST_BUTTON				(4)				// first push button
#define EZ_LAST_BUTTON				(7)				// last push button
#endif

#if defined(__ADSP_BRAEMAR__)			// ADSP-BF537 EZ-Kit specific info
#define EZ_FIRST_LED				(1)				// first LED number
#define EZ_LAST_LED					(6)				// last LED number
#define EZ_FIRST_BUTTON				(1)				// first push button
#define EZ_LAST_BUTTON				(4)				// last push button
#endif

#if defined (__ADSP_TETON__) 

#define EZ_FIRST_LED				(5)					// first LED number
#define EZ_LAST_LED					(20)				// last LED number
#define EZ_FIRST_BUTTON				(6)					// first push button
#define EZ_LAST_BUTTON				(9)					// last push button

#endif

/*********************************************************************

Button/LED to Flag pin mappings

*********************************************************************/

#if defined(__ADSP_EDINBURGH__)			// ADSP-BF533 EZ-Kit specific info
ADI_FLAG_ID Button[];
ADI_FLAG_ID LED[];
#endif

#if defined(__ADSP_BRAEMAR__)			// ADSP-BF537 EZ-Kit specific info
ADI_FLAG_ID Button[];
ADI_FLAG_ID LED[];
#endif


#if defined(__ADSP_TETON__)				// ADSP-BF561 EZ-Kit specific info
ADI_FLAG_ID LED[];
ADI_FLAG_ID Button[];
#endif

/*********************************************************************

Functions provided by the utilities

*********************************************************************/

void	ezInit						(u8 NumCores); 		// Initializes the EZ-Kit utilities
// The following 'Init' functions are all incorporated in the single call to ezInit, 
// but are available for separate use where required.
void ezInitPower					(u8 NumCores);		// initializes power to max speed
void ezInitLEDs						(void);				// initialized LEDs
void ezInitButtons					(void);				// initializes buttons

#if defined(__ADSP_EDINBURGH__)			// ADSP-BF533 EZ-Kit specific info
void ezInitAsync					(void);				// configures async memory for use
void ezInitFlashA					(void);				// sets up the flash
#endif

void	ezTerminate					(void); 			// Terminates ezkitUtilities 
// The following 'Terminate' functions are all incorporated in the single call to ezTerminate, 
// but are available for separate use where required.
void ezTerminateLEDs				(void);				// terminates LEDs
void ezTerminateButtons				(void);				// terminates buttons


void 	ezEnableVideoEncoder		(void);				// enables the 7183 video encoder
void 	ezEnableVideoDecoder		(void);				// enables the 7171 video decoder
void 	ezDisableVideoDecoder		(void);				// releases PF2 pin from Flag Manager control


void 	ezTurnOnLED					(u32 LEDNumber);	// turns on an LED
void 	ezTurnOffLED				(u32 LEDNumber);	// turns off an LED
void 	ezToggleLED					(u32 LEDNumber);	// toggles an LED
u32 	ezIsLEDOn					(u32 LEDNumber);	// test to see if an LED is lit
void 	ezTurnOnAllLEDs				(void);				// turns on all LEDs
void 	ezTurnOffAllLEDs			(void);				// turns off all LEDs
void 	ezCycleLEDs					(void);				// cycles through LEDS
u32		ezGetDisplay				(void);				// returns the current bit pattern for the LED display
void 	ezSetDisplay				(u32 Display);		// sets the LED display for the given bit pattern


u32		ezIsButtonPushed			(u32 ButtonNumber);	// is a push button pressed (TRUE - pressed/FALSE - not pressed)
void	ezClearButton				(u32 ButtonNumber);	// clears the push button latch
u32		ezDisableButtonCallback		(u32 ButtonNumber);	// disables generation of a push button callback
u32		ezEnableButtonCallback		(					// enables generation of a push button callback
	u32 				ButtonNumber,
	void				*ClientHandle,
	ADI_DCB_HANDLE		DCBHandle,
	ADI_DCB_CALLBACK_FN	ClientCallback
);	


void 	ezErrorCheck				(u32 Result);		// lights all LEDS and spins on nonzero value


#endif	
	
	
	
		
	



